@@ -23,6 +23,9 @@ from primaryschool.resource import (
 )
 from primaryschool.settings import *
 from primaryschool.subjects import subjects
+import webbrowser
+from primaryschool.dirs import user_screenshot_dir_path
+import subprocess
 
 app_description_t = _("app_description_t")
 
@@ -172,6 +175,8 @@ class PlayMenu:
         self.selection_box_bgcolor = (255, 255, 255)
         self.help_lael = None
         self.help_lael_font = get_default_font(20)
+        self.esc_lael_font = get_default_font(16)
+        self.esc_lael_font.set_bold(True)
         self.help_lael_bg = (228, 0, 252, 30)
         self.help_lael_border_color = (228, 0, 252, 200)
 
@@ -248,6 +253,12 @@ class PlayMenu:
         )
         self.update_help_lael()
 
+        self._menu.add.label(
+            _("After starting the game, press ESC to return."),
+            font_name=self.esc_lael_font,
+            font_color=(255, 0, 0),
+        )
+
     def update_selection_box_width(self):
         for ds in [
             self.subject_dropselect,
@@ -341,6 +352,16 @@ class MainMenu:
         self.play_menu = self.ps.play_menu
         self.about_menu = self.ps.about_menu
 
+    def open_screenshots_dir(self):
+        _open = (
+            sys.platform == "darwin"
+            and "open"
+            or sys.platform == "win32"
+            and "explorer"
+            or "xdg-open"
+        )
+        subprocess.Popen([_open, user_screenshot_dir_path])
+
     def add_widgets(self):
         self._menu.add.button(
             _("Play"),
@@ -357,13 +378,21 @@ class MainMenu:
             pygame_menu.events.EXIT,
             font_name=self.ps.font_path,
         )
+        self._menu.add.button(
+            _("Screenshots"),
+            self.open_screenshots_dir,
+            font_name=self.ps.font_path,
+            align=pygame_menu.locals.ALIGN_RIGHT,
+            background_color=(100, 20, 20, 50),
+            font_color=(20, 20, 100),
+        )
 
 
 class PrimarySchool:
     def __init__(self):
         pygame.init()
         self.running = True
-        self.surface = pygame.display.set_mode((0, 0), pygame.RESIZABLE)
+        self.surface = pygame.display.set_mode((0, 0), pygame.FULLSCREEN)
         self.w_width, self.w_height = self.surface.get_size()
         self.w_width_of_2 = self.w_width / 2
         self.w_height_of_2 = self.w_height / 2
