@@ -1,4 +1,3 @@
-
 import copy
 import os
 import pickle
@@ -15,7 +14,11 @@ from xpinyin import Pinyin
 
 from primaryschool.dirs import *
 from primaryschool.locale import _, sys_lang_code
-from primaryschool.resource import (default_font, default_font_path,
-                                    get_default_font, get_font_path)
+from primaryschool.resource import (
+    default_font,
+    default_font_path,
+    get_default_font,
+    get_font_path,
+)
 from primaryschool.subjects import *
 from primaryschool.subjects._abc_ import GameBase
