@@ -54,7 +54,7 @@ Enter the corresponding words of the Chinese characters.
 
 class ZhCNEmTargetsManager(TargetsManager):
     def __init__(self, shtbase):
-        super().__init__(shtbase, target_surface_lang_code="zh_CN")
+        super().__init__(shtbase, lang_code="zh_CN")
         self.wave = ShootingWave(self)
 
     def blit_intercepting(self, moving_surfaces):
